@@ -112,7 +112,7 @@ file_save_ok_cb (GtkDialog *file_sel,
 	/* Check permissions */
 
 	dir = remove_level_from_path (filename);
-	if (access (dir, R_OK | W_OK | X_OK) != 0) {
+	if (! check_permissions (dir, R_OK | W_OK | X_OK)) {
 		char *utf8_path;
 		utf8_path = g_filename_to_utf8 (dir, -1, NULL, NULL, NULL);
 		_gtk_error_dialog_run (parent,
@@ -354,7 +354,7 @@ get_type_from_name (const char *name)
 	int i;
 
 	for (i = 0; types_table[i].name != NULL; i++)
-		if (strcmp (types_table[i].name, name) == 0) 
+		if (strcasecmp (types_table[i].name, name) == 0) 
 			return types_table + i;
 	
 	return NULL;
