@@ -72,7 +72,8 @@ typedef struct {
 
 	GtkWidget          *btn_ok;
 
-	GtkWidget          *wa_destination_combo_entry;
+	GtkWidget          *wa_destination_entry;
+	GtkWidget          *wa_destination_button;
 	GtkWidget          *wa_index_file_entry;
 	GtkWidget          *wa_copy_images_checkbutton;
 	GtkWidget          *wa_resize_images_checkbutton;
@@ -122,7 +123,7 @@ export (GtkWidget  *widget,
 
 	/* Save options. */
 
-	path = _gtk_entry_get_filename_text (GTK_ENTRY (data->wa_destination_combo_entry));
+	path = _gtk_entry_get_filename_text (GTK_ENTRY (data->wa_destination_entry));
 	location = remove_ending_separator (path);
 	g_free (path);
 	eel_gconf_set_path (PREF_WEB_ALBUM_DESTINATION, location);
@@ -270,6 +271,50 @@ resize_image_toggled_cb (GtkToggleButton *button,
 }
 
 
+static void
+open_response_cb (GtkDialog  *file_sel,
+		  int         button_number,
+		  gpointer    userdata)
+{
+	DialogData  *data = (DialogData   * )userdata;
+
+	if (button_number == GTK_RESPONSE_ACCEPT) {
+		_gtk_entry_set_filename_text (GTK_ENTRY (data->wa_destination_entry),
+					      gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (file_sel)));
+	}
+	gtk_widget_destroy (GTK_WIDGET (file_sel));
+}
+
+
+static void
+wa_destination_button_clicked_cb (GtkWidget  *button,
+				  gpointer    data)
+{
+	GtkWidget *file_sel;
+	
+	file_sel = gtk_file_chooser_dialog_new (_("Choose destination folder"),
+						NULL,
+						GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER, 
+						GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, 
+						GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+						NULL);
+	gtk_window_set_modal (GTK_WINDOW (file_sel), TRUE);
+
+	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (file_sel), FALSE);
+	g_signal_connect (G_OBJECT (file_sel),
+			  "response",
+			  G_CALLBACK (open_response_cb),
+			  data);
+	
+	g_signal_connect_swapped (GTK_DIALOG (file_sel),
+				  "close",
+				  G_CALLBACK (gtk_widget_destroy),
+				  GTK_WIDGET (file_sel));
+	
+	gtk_widget_show_all (GTK_WIDGET (file_sel));
+}
+
+
 /* create the main dialog. */
 void
 dlg_web_exporter (GThumbWindow *window)
@@ -304,9 +349,10 @@ dlg_web_exporter (GThumbWindow *window)
         }
 
 	/* Get the widgets. */
-
+	
 	data->dialog = glade_xml_get_widget (data->gui, "web_album_dialog");
-	data->wa_destination_combo_entry = glade_xml_get_widget (data->gui, "wa_destination_combo_entry");
+	data->wa_destination_entry = glade_xml_get_widget (data->gui, "wa_destination_entry");
+	data->wa_destination_button = glade_xml_get_widget (data->gui, "wa_destination_button");
 	data->wa_index_file_entry = glade_xml_get_widget (data->gui, "wa_index_file_entry");
 	data->wa_copy_images_checkbutton = glade_xml_get_widget (data->gui, "wa_copy_images_checkbutton");
 
@@ -325,9 +371,6 @@ dlg_web_exporter (GThumbWindow *window)
 	data->wa_theme_combo_entry = glade_xml_get_widget (data->gui, "wa_theme_combo_entry");
 	data->wa_select_theme_button = glade_xml_get_widget (data->gui, "wa_select_theme_button");
 
-	/**/
-
-
 	/**/
 
 	data->progress_dialog = glade_xml_get_widget (data->gui, "progress_dialog");
@@ -381,7 +424,7 @@ dlg_web_exporter (GThumbWindow *window)
 	/**/
 
 	svalue = eel_gconf_get_path (PREF_WEB_ALBUM_DESTINATION, NULL);
-	_gtk_entry_set_filename_text (GTK_ENTRY (data->wa_destination_combo_entry),
+	_gtk_entry_set_filename_text (GTK_ENTRY (data->wa_destination_entry),
 				      (((svalue == NULL) || (*svalue == 0)) ? g_get_home_dir() : svalue));
 	g_free (svalue);
 
@@ -391,6 +434,10 @@ dlg_web_exporter (GThumbWindow *window)
 			  "destroy",
 			  G_CALLBACK (destroy_cb),
 			  data);
+	g_signal_connect (G_OBJECT (data->wa_destination_button), 
+			  "clicked",
+			  G_CALLBACK (wa_destination_button_clicked_cb),
+			  data);
 	g_signal_connect_swapped (G_OBJECT (btn_cancel), 
 				  "clicked",
 				  G_CALLBACK (gtk_widget_destroy),
@@ -442,7 +489,7 @@ dlg_web_exporter (GThumbWindow *window)
 
 	/* Run dialog. */
 
-	gtk_widget_grab_focus (data->wa_destination_combo_entry);
+	gtk_widget_grab_focus (data->wa_destination_entry);
 
 	gtk_window_set_transient_for (GTK_WINDOW (data->dialog), GTK_WINDOW (window->app));
 	gtk_window_set_modal (GTK_WINDOW (data->dialog), FALSE);
@@ -629,18 +676,18 @@ ensure_local_theme_dir_exists (void)
 
 
 static void
-install_theme__ok_cb (GObject  *object,
-		      gpointer  data)
+install_theme__ok_cb (GtkDialog  *file_sel,
+		      int         button_number,
+		      gpointer    data)
 {
 	ThemeDialogData  *tdata;
-	GtkWidget        *file_sel = data;
 	char             *theme_archive;
 	char             *command_line = NULL;
 	GError           *err = NULL;
 
 	tdata = g_object_get_data (G_OBJECT (file_sel), "theme_dialog_data");
-	theme_archive = g_strdup (gtk_file_selection_get_filename (GTK_FILE_SELECTION (file_sel)));
-	gtk_widget_destroy (file_sel);
+	theme_archive = g_strdup (gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (file_sel)));
+	gtk_widget_destroy (GTK_WIDGET (file_sel));
 
 	if (theme_archive == NULL)
 		return;
@@ -677,6 +724,18 @@ install_theme__ok_cb (GObject  *object,
 }
 
 
+static void
+install_theme_response_cb (GtkDialog  *file_sel,
+			   int         button_number,
+			   gpointer    userdata)
+{
+	if (button_number == GTK_RESPONSE_ACCEPT) 
+		install_theme__ok_cb (file_sel, button_number, userdata);
+	 else 
+		gtk_widget_destroy (GTK_WIDGET (file_sel));
+}
+
+
 static void
 theme_dialog__install_theme_clicked (GtkWidget       *widget, 
 				     ThemeDialogData *tdata)
@@ -684,22 +743,22 @@ theme_dialog__install_theme_clicked (GtkWidget       *widget,
 	GtkWidget *file_sel;
 	char      *home;
 
-	file_sel = gtk_file_selection_new (_("Select Album Theme"));
+	file_sel = gtk_file_chooser_dialog_new (_("Select Album Theme"), NULL,
+						GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
+						GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+						GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+						NULL);
+	gtk_window_set_modal (GTK_WINDOW (file_sel), TRUE);
 	g_object_set_data (G_OBJECT (file_sel), "theme_dialog_data", tdata);
 
 	home = g_strconcat (g_get_home_dir (), "/", NULL);
-	gtk_file_selection_set_filename (GTK_FILE_SELECTION (file_sel), home);
+	gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (file_sel), home);
 	g_free (home);
 
-	g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (file_sel)->ok_button),
-			  "clicked",
-			  G_CALLBACK (install_theme__ok_cb),
-			  file_sel);
-
-	g_signal_connect_swapped (G_OBJECT (GTK_FILE_SELECTION (file_sel)->cancel_button),
-				  "clicked",
-				  G_CALLBACK (gtk_widget_destroy),
-				  G_OBJECT (file_sel));
+	g_signal_connect (GTK_DIALOG (file_sel),
+			  "response",
+			  G_CALLBACK (install_theme_response_cb),
+			  NULL);
 
 	gtk_window_set_transient_for (GTK_WINDOW (file_sel),
 				      GTK_WINDOW (tdata->dialog));
